@@ -390,7 +390,8 @@ sub install_module {
     $mainFile = "$mainFile/index.js" if -d $mainFile;
     warning "MAIN: $mainFile\n" if (DEBUG);
     $mainFile =~ s#//+#/#g;
-    my $foundMain = 0;
+    my $foundMain    = 0;
+    my $foundPkgJson = 0;
 
     foreach my $p (@files) {
         my $pattern;
@@ -466,7 +467,9 @@ sub install_module {
                 else {
                     unless ( grep { $_ } @tests ) {
                         push @dest, [ $d, $File::Find::name ];
-                        $foundMain = 1 if $File::Find::name eq $mainFile;
+                        $foundMain    = 1 if $File::Find::name eq $mainFile;
+                        $foundPkgJson = 1
+                          if $File::Find::name eq 'package.json';
                     }
 
                     # Debug
@@ -507,6 +510,9 @@ EOF
             push @dest, [ $ldir, $mainFile ];
         }
     }
+    unless ($foundPkgJson) {
+        push @dest, [ '', "$dir/package.json" ];
+    }
     foreach (@dest) {
         $self->doit_in_builddir( 'mkdir', '-p', "$path/$_->[0]" )
           unless doit_noerror( { chdir => $self->get_buildpath },
