@@ -79,7 +79,7 @@ sub git_last_version {
               sort {
                 Dpkg::Version->new( "$a-0", check => 0 )
                   cmp Dpkg::Version->new( "$b-0", check => 0 )
-              } ( $response->content =~ m#.*/archive/v?([\d\.]+).tar.gz#g );
+              } ( $response->content =~ m#.*/archive.*/v?([\d\.]+).tar.gz#g );
             return @versions ? pop(@versions) : 0;
         }
     }
@@ -103,7 +103,7 @@ sub git_watch {
 opts=\\
 ${component}dversionmangle=auto,\\
 filenamemangle=s/.*\\/v?([\\d\\.-]+)\\.tar\\.gz/node-$name-\$1.tar.gz/ \\
- $repo/tags$after .*/archive/$version.tar.gz$type
+ $repo/tags$after .*/archive.*/$version.tar.gz$type
 EOF
     }
     else {
